{ name, ... }:
{
  disko.devices = {
    disk = {
      "${name}" = {
        type = "disk";
        device = "/dev/nvme0n1";
        content = {
          type = "gpt";
          partitions = {
            boot = {
              size = "1M";
              type = "EF02";
            };
            ESP = {
              size = "2G";
              type = "EF00";
              content = {
                type = "filesystem";
                format = "vfat";
                mountpoint = "/boot";
                mountOptions = [ "umask=0077" ];
              };
            };
            luks = {
              size = "100%";
              content = {
                type = "luks";
                name = "${name}-disk";
                settings.allowDiscards = true;
                passwordFile = "/tmp/secret.key";
                content = {
                  type = "lvm_pv";
                  vg = "${name}";
                };
              };
            };
          };
        };
      };
    };

    lvm_vg = {
      "${name}" = {
        type = "lvm_vg";
        lvs = {
          root = {
            size = "100%";
            content = {
              type = "btrfs";
              extraArgs = [ "-f" ];
              subvolumes = {
                "/root" = {
                  mountpoint = "/";
                  mountOptions = [ "compress=zstd" ];
                };
                "/prev" = {
                  mountpoint = "/prev";
                  mountOptions = [
                    "compress=zstd"
                    "noexec"
                  ];
                };
                "/nix" = {
                  mountpoint = "/nix";
                  mountOptions = [ "compress=zstd" ];
                };

	        # Impermanence
	        "/persist" = {
	          mountpoint = "/persist";
	          mountOptions = [ "compress=zstd" ];
	        };
                "/persist/.snapshots" = { };
                "/persist/home" = { };
                "/persist/home/.snapshots" = { };
              };
            };
          };
          swap = {
            size = "8G";
            content = {
              type = "swap";
              discardPolicy = "both";
            };
          };
        };
      };
    };
  };

  # Needed for impermanence
  fileSystems."/persist".neededForBoot = true;
}
